######
opinel
######

.. image:: https://travis-ci.org/iSECPartners/opinel.svg?branch=master
        :target: https://travis-ci.org/iSECPartners/opinel

************
Introduction
************

opinel is the Python package used by `Scout2`_ and `AWS-Recipes`_.

************
Installation
************

Install via `pip`_:

::

    $ pip install opinel

Install from source:

::

    $ git clone https://github.com/iSECPartners/opinel
    $ cd opinel
    $ python setup.py install

.. _Scout2: https://github.com/iSECPartners/Scout2
.. _AWS-Recipes: https://github.com/iSECPartners/AWS-Recipes
.. _pip: https://pip.pypa.io/en/stable/index.html
